==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/inputs/ListIdentityProviderSecretsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin.inputs

import com.pulumi.azurenative.apimanagement.inputs.ListIdentityProviderSecretsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property identityProviderName Identity Provider Type identifier.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property serviceName The name of the API Management service.
 */
public data class ListIdentityProviderSecretsPlainArgs(
    public val identityProviderName: String,
    public val resourceGroupName: String,
    public val serviceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.apimanagement.inputs.ListIdentityProviderSecretsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.apimanagement.inputs.ListIdentityProviderSecretsPlainArgs =
        com.pulumi.azurenative.apimanagement.inputs.ListIdentityProviderSecretsPlainArgs.builder()
            .identityProviderName(identityProviderName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListIdentityProviderSecretsPlainArgs].
 */
@PulumiTagMarker
public class ListIdentityProviderSecretsPlainArgsBuilder internal constructor() {
    private var identityProviderName: String? = null

    private var resourceGroupName: String? = null

    private var serviceName: String? = null

    /**
     * @param value Identity Provider Type identifier.
     */
    @JvmName("qoniqsuxfjpekkjc")
    public suspend fun identityProviderName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.identityProviderName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("vosdecuuxdwxsgnq")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the API Management service.
     */
    @JvmName("sidyqgdnkvncapia")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): ListIdentityProviderSecretsPlainArgs = ListIdentityProviderSecretsPlainArgs(
        identityProviderName = identityProviderName ?: throw
            PulumiNullFieldException("identityProviderName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/inputs/ListIdentityProviderSecretsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin.inputs

import com.pulumi.azurenative.apimanagement.inputs.ListIdentityProviderSecretsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property identityProviderName Identity Provider Type identifier.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property serviceName The name of the API Management service.
 */
public data class ListIdentityProviderSecretsPlainArgs(
    public val identityProviderName: String,
    public val resourceGroupName: String,
    public val serviceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.apimanagement.inputs.ListIdentityProviderSecretsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.apimanagement.inputs.ListIdentityProviderSecretsPlainArgs =
        com.pulumi.azurenative.apimanagement.inputs.ListIdentityProviderSecretsPlainArgs.builder()
            .identityProviderName(identityProviderName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListIdentityProviderSecretsPlainArgs].
 */
@PulumiTagMarker
public class ListIdentityProviderSecretsPlainArgsBuilder internal constructor() {
    private var identityProviderName: String? = null

    private var resourceGroupName: String? = null

    private var serviceName: String? = null

    /**
     * @param value Identity Provider Type identifier.
     */
    @JvmName("jlggpvbebymfhygm")
    public suspend fun identityProviderName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.identityProviderName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("vvoryhoeplmqgrkq")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the API Management service.
     */
    @JvmName("dvcooteoyxqeacgw")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): ListIdentityProviderSecretsPlainArgs = ListIdentityProviderSecretsPlainArgs(
        identityProviderName = identityProviderName ?: throw
            PulumiNullFieldException("identityProviderName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
    )
}
